==> cxxtools_2.0.orig.tar.gz: cxxtools-2.0/src/xml/startelement.cpp <==
/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * As a special exception, you may use this file as part of a free
 * software library without restriction. Specifically, if other files
 * instantiate templates or use macros or inline functions from this
 * file, or you compile this file and link it with other files to
 * produce an executable, this file does not by itself cause the
 * resulting executable to be covered by the GNU General Public
 * License. This exception does not however invalidate any other
 * reasons why the executable file might be covered by the GNU Library
 * General Public License.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "cxxtools/xml/startelement.h"

namespace cxxtools {

namespace xml {

Attribute::Attribute()
{
}


Attribute::Attribute(const String& name, const String& value) 
: _name(name), _value(value)
{
}


Attribute::~Attribute()
{
}





StartElement::StartElement() 
: Node(Node::StartElement)
{

}


StartElement::StartElement(const String& name)
: Node(Node::StartElement),
  _name(name)
{
}


StartElement::~StartElement()
{
}


const String& StartElement::attribute(const String attributeName) const
{
    static const String null;
    
    for(std::list<Attribute>::const_iterator it = _attributes.begin(); it != _attributes.end(); ++it) {
        if(it->name() == attributeName) {
            return it->value();
        }
    }
    
    return null;
}


bool StartElement::hasAttribute(const String attributeName) const
{
    for(std::list<Attribute>::const_iterator it = _attributes.begin(); it != _attributes.end(); ++it) {
        if(it->name() == attributeName) {
            return true;
        }
    }
    
    return false;
}


bool StartElement::operator==(const Node& node) const
{
    const StartElement* se = dynamic_cast<const StartElement*>(&node);
    if(!se) return false;

    return ( se->name() == this->name() );
}

} // namespace xml

} // namespace cxxtools

==> cxxtools_2.2.1.orig.tar.gz: cxxtools-2.2.1/src/xml/startelement.cpp <==
/*
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * As a special exception, you may use this file as part of a free
 * software library without restriction. Specifically, if other files
 * instantiate templates or use macros or inline functions from this
 * file, or you compile this file and link it with other files to
 * produce an executable, this file does not by itself cause the
 * resulting executable to be covered by the GNU General Public
 * License. This exception does not however invalidate any other
 * reasons why the executable file might be covered by the GNU Library
 * General Public License.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "cxxtools/xml/startelement.h"

namespace cxxtools {

namespace xml {


const String& StartElement::attribute(const String& attributeName) const
{
    static const String null;
    
    for(std::list<Attribute>::const_iterator it = _attributes.begin(); it != _attributes.end(); ++it) {
        if(it->name() == attributeName) {
            return it->value();
        }
    }
    
    return null;
}


bool StartElement::hasAttribute(const String& attributeName) const
{
    for(std::list<Attribute>::const_iterator it = _attributes.begin(); it != _attributes.end(); ++it) {
        if(it->name() == attributeName) {
            return true;
        }
    }
    
    return false;
}


bool StartElement::operator==(const Node& node) const
{
    const StartElement* se = dynamic_cast<const StartElement*>(&node);
    if(!se) return false;

    return ( se->name() == this->name() );
}

} // namespace xml

} // namespace cxxtools
